@@ -3,6 +3,8 @@
 import math
 import numpy as np
 
+__all__ = ["add", "sub", "subtract"]
+
 def add(*args):
     """
     Add numbers together
@@ -25,3 +27,5 @@ def sub(*args):
         diff_result -= number
     remainders = diff_result%int(diff_result)
     return int(diff_result) if remainders==0 else diff_result
+
+subtract = sub
\ No newline at end of file
